===============================
Alternatives to django Organice
===============================

With django Organice we strive to make people happy who are not tech or process experts.  People who want to
collaborate smoothly without having taken part of extensive training programmes in order to understand the tool.
Simplicity is key, everything should be intuitive, getting things done easily.  Occasional users should be happy
to the same extent than daily-habit expert users.

Naturally though, django Organice isn't a fit for everyone.  If you feel it can't satisfy your specific needs
it may be a good idea to look at the following alternatives.  If you happen to know additional offers
`drop us a note`_ so we can make the list more complete.

Software Alternatives
=====================

In alphabetical order.

- `Bitrix Intranet`_ (PHP, commercial, ships with source code)
- `Coyo`_ (Java/Play, commercial, ships with source code)
- `Fairgate`_ (PHP, commercial, Switzerland only)
- `Microsoft SharePoint + Yammer`_ [1]_ (.NET + Rails, commercial)
- `Odoo`_ (Python, open source)
- `Open Atrium`_ (Drupal, open source)
- `teamraum Enterprise`_ (Django, commercial)
- `tendenci`_ (Django, open source)

Cloud Competitors
=================

In alphabetical order.

- `Bitrix24.com`_ / `Bitrix24.de`_ [1]_
- `huddle`_
- `Igloo`_
- `Odoo`_
- `teamraum`_


.. _drop us a note: info@organice.io
.. _Bitrix Intranet: http://www.bitrixsoft.com/products/intranet/
.. _Coyo: https://www.coyoapp.com/
.. _Fairgate: http://www.pitsolutions.ch/case-studies/php/fairgate-ag/
.. _Microsoft SharePoint + Yammer: http://office.microsoft.com/sharepoint/
.. _Open Atrium: https://drupal.org/project/openatrium
.. _Odoo: https://github.com/odoo/odoo
.. _teamraum Enterprise: https://www.4teamwork.ch/loesungen/teamraum/
.. _tendenci: http://tendenci.com/features/
.. _Bitrix24.com: http://bitrix24.com/
.. _Bitrix24.de: http://bitrix24.de/
.. _huddle: http://www.huddle.com/
.. _Igloo: http://www.igloosoftware.com/
.. _teamraum: http://www.teamraum.com/

.. [1] http://intranetsdoneright.blogspot.com/2013/11/what-is-social-intranet.html
